@@ -1,8 +1,8 @@
-# $Revision: #44 $$Date: 2004/10/26 $$Author: ws150726 $
+# $Revision: 1.48 $$Date: 2005/01/13 18:23:42 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2004 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2005 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -16,7 +16,7 @@
 package SystemC::Vregs::TableExtract;
 
 @ISA = qw(HTML::TableExtract);
-$VERSION = '1.246';
+$VERSION = '1.250';
 
 use strict;
 use vars qw($Debug %Find_Start_Headers %Find_Headers);
@@ -29,6 +29,7 @@ use HTML::Entities ();
 		       Defines=>1,
 		       Enum=>1,
 		       Register=>1,
+		       TableExtract_End_Of_File=>1,
 		       );
 %Find_Headers = (%Find_Start_Headers,
 		 Address=>1,
@@ -47,7 +48,7 @@ sub parse_file {
     $self->{_vregs_num_tables} = -1;
     $self->SUPER::parse_file ($fh);
     $self->start("p");
-    $self->text("Register");
+    $self->text("TableExtract_End_Of_File");
     $fh->close();
 }
 
@@ -82,21 +83,17 @@ sub clean_html_text {
     s/\264/\'/g;	# ISO-Latin1 spacing acute
     s/\267/\*/g;	# ISO-Latin1 middle dot (0xB7)
     # These are automatically removed by HTML::Entities in Perl 5.7 and greater
+    # Also decode unicode sequences decoded by perl 5.8.*
     s/\&\#8209;/-/g;	# ISOpub nonbreaking hyphen (U+2011, &#8209;)
-    s/\&\#8211;/-/g;	# ISOpub en-dash (U+2013, &#8211;)
-    s/\&ndash;/-/g;	# ISOpub en-dash (U+2013, &#8211;)
-    s/\&\#8212;/-/g;	# ISOpub em-dash (U+2014, &#8212;)
-    s/\&mdash;/-/g;	# ISOpub em-dash (U+2014, &#8212;)
-    s/\&\#8216;/\'/g;	# ISOnum left single-quote (U+2018, &#8216;)
-    s/\&lsquo;/\'/g;	# ISOnum left single-quote (U+2018, &#8216;)
-    s/\&\#8217;/\'/g;	# ISOnum right single-quote (U+2019, &#8217;)
-    s/\&rsquo;/\'/g;	# ISOnum right single-quote (U+2019, &#8217;)
-    s/\&\#8220;/\"/g;	# ISOnum left double-quote (U+201C, &#8220;)
-    s/\&ldquo;/\"/g;	# ISOnum left double-quote (U+201C, &#8220;)
-    s/\&\#8221;/\"/g;	# ISOnum right double-quote (U+201D, &#8221;)
-    s/\&rdquo;/\"/g;	# ISOnum right double-quote (U+201D, &#8221;)
-    s/\&\#8230;/-/g;	# ISOpub horizontal elipses (U+2026, &#8230;)
-    s/\&hellip;/-/g;	# ISOpub horizontal elipses (U+2026, &#8230;)
+    s/\&\#8211;/-/g;	s/\&ndash;/-/g;  s/\342\200\041/\-/g;	# ISOpub en-dash (U+2013, &#8211;)
+    s/\&\#8212;/-/g;	s/\&mdash;/-/g;  s/\342\200\042/\-/g;	# ISOpub em-dash (U+2014, &#8212;)
+    s/\&\#8216;/\'/g;	s/\&lsquo;/\'/g; s/\342\200\176/\`/g;	# ISOnum left single-quote (U+2018, &#8216;)
+    s/\&\#8217;/\'/g;	s/\&rsquo;/\'/g; s/\342\200\177/\`/g;	# ISOnum right single-quote (U+2019, &#8217;)
+    ; 					 s/\342\200\230/\`/g;	# ISOnum left single-quote (U+2018, &#8216;)
+    ; 					 s/\342\200\231/\`/g;	# ISOnum right single-quote (U+2019, &#8217;)
+    s/\&\#8220;/\"/g;	s/\&ldquo;/\"/g; s/\342\200\234/\"/g;	# ISOnum left double-quote (U+201C, &#8220;)
+    s/\&\#8221;/\"/g;	s/\&rdquo;/\"/g; s/\342\200\235/\"/g;	# ISOnum right double-quote (U+201D, &#8221;)
+    s/\&\#8230;/-/g;	s/\&hellip;/-/g; s/\342\200\174/-/g;	# ISOpub horizontal elipses (U+2026, &#8230;)
     # Compress spacing
     s/\`/\'/g;
     s/[\t\n\r ]+/ /g;
@@ -116,7 +113,7 @@ sub start {
 sub end {
     my $self = shift;
     if ($_[0] eq 'p') {
-	print "<\/p>\n" if $Debug;
+	print "<\/$_[0]>\n" if $Debug;
 	if (!$self->{_vregs_first_endp}) {
 	    $self->{_vregs_first_endp} = 1;
 	} else {
@@ -130,10 +127,13 @@ sub text {
     my $self = shift;
     # Don't bother if we are in a table
     if (! $self->{_in_a_table}) {
-	$_ = $_[0];
-	printf +("Text %s: %s:|%s|\n", $self->{_fh}->tell(),
-		 ($self->{_vregs_first_word_in_p}?"FW":"  "),$_) if $Debug;
-	my $text = clean_html_text($_);
+	my $text = $_[0];
+	if ($Debug) {
+	    (my $printtext = $text) =~ s/[\n \t]+/ /g;
+	    printf +("Text %s: %s:|%s|\n", $self->{_fh}->tell(),
+		     ($self->{_vregs_first_word_in_p}?"FW":"  "),$printtext);
+	}
+	$text = clean_html_text($text);
 	if ($text !~ /^\s*$/
 	    && $text !~ /^</) {
 	    my $nosp_text = $text;
@@ -151,7 +151,8 @@ sub text {
 	    if ($self->{_vregs_first_word_in_p}
 		&& $Find_Headers{$nosp_text}) {
 		print "Keyword '$text'\n" if $Debug;
-		if ($Find_Start_Headers{$text}) {
+		if ($Find_Start_Headers{$text}
+		    && $self->{_vregs_next}) {
 		    # Process previous entry, and prepare for next discovery
 		    my $pack = $self->{_vregs_pack};
 		    $pack->new_item([], $self->{_vregs_next});  # note no table
@@ -163,6 +164,7 @@ sub text {
 		$self->{_vregs_next_tag} = $text;
                 $self->{_vregs_next}{$self->{_vregs_next_tag}} = "";
                 $self->{_vregs_first_endp} = 0;
+                $self->{_vregs_next} = undef if $text eq 'TableExtract_End_Of_File';
 	    }
 	    elsif ($self->{_vregs_next_tag}) {
 		print "TAG '$self->{_vregs_next_tag}' '$text'\n" if $Debug;
@@ -174,23 +176,26 @@ sub text {
 	my $numtables = ();
 	if ($#tables != $self->{_vregs_num_tables}) {
 	    $self->{_vregs_num_tables} = $#tables;
-	    my $table = $tables[$#tables];
-	    # Clean up the table to remove extra spaces in the tables
-	    my @bittable = ($table->rows);
-	    foreach my $row (@bittable) {
-		@$row = map {
-		    $_ = clean_html_text($_);
-		    $_ =~ s/<[^>]+>//ig; #$_="" if /SupportEmptyParas/i;  # Microsloth Word junk
-		    $_ =~ s/^[ \t\n\r]+//sig;
-		    $_ =~ s/[ \t\n\r]+$//sig;
-		    $_;
-		} @$row;
+	    if ($self->{_vregs_next}) {  # else a table outside of a register decl
+		my $table = $tables[$#tables];
+		# Clean up the table to remove extra spaces in the tables
+		my @bittable = ($table->rows);
+		foreach my $row (@bittable) {
+		    @$row = map {
+			$_ = clean_html_text($_);
+			$_ =~ s/<[^>]+>//ig; #$_="" if /SupportEmptyParas/i;  # Microsloth Word junk
+			$_ =~ s/^[ \t\n\r]+//sig;
+			$_ =~ s/[ \t\n\r]+$//sig;
+			$_;
+		    } @$row;
+		}
+		# Process this, and prepare for next discovery
+		my $pack = $self->{_vregs_pack};
+		print ::Dumper(\@bittable, $self->{_vregs_next}) if $Debug;
+		$pack->new_item(\@bittable, $self->{_vregs_next});
+		$self->{_vregs_next} = undef;
+		$self->{_vregs_next_tag} = undef;
 	    }
-	    # Process this, and prepare for next discovery
-	    my $pack = $self->{_vregs_pack};
-	    print ::Dumper(\@bittable, $self->{_vregs_next}) if $Debug;
-	    $pack->new_item(\@bittable, $self->{_vregs_next});
-	    $self->{_vregs_next} = undef;
 	}
     }
     $self->SUPER::text (@_);
@@ -256,7 +261,7 @@ It is designed to be used by SystemC::Vregs only.
 
 The latest version is available from CPAN and from L<http://www.veripool.com/>.
 
-Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2005 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
